@@ -28,7 +28,7 @@ def lint(session: nox.Session) -> None:
     args = *(session.posargs or ("--show-diff-on-failure",)), "--all-files"
     session.run("pre-commit", "run", *args)
     session.run("python", "-m", "mypy")
-    session.run("python", "-m", "pylint", "src", "cli.py")
+    session.run("python", "-m", "pylint", "src")
 
 
 @nox.session
